@@ -302,7 +302,8 @@ def test_repo(**kwargs):
 def push_coverage():
     _logger.warning("Deprecated command ' - vxci push_coverage'. "
                     "Use\n - source variables.sh\n - vxci push_coverage_combine")
-    push_coverage_result()
+    push_status = push_coverage_result()
+    exit(not push_status)
 
 
 @cli.command()
@@ -341,17 +342,17 @@ def push_coverage():
                     "Env var: CI_COMMIT_SHA."))
 def push_coverage_combine(**kwargs):
     config = common.prepare(**kwargs)
-    status, msg = generate_coverage_reports(config)
+    report_status, msg = generate_coverage_reports(config)
 
-    if status:
+    if report_status:
         green_pattern = "\033[1;32m\033[1;49m%s\033[0m"
         _logger.info(green_pattern, "Coverage succeeded!")
     else:
         red_pattern = "\033[1;31m\033[1;49m%s\033[0m"
         _logger.error(red_pattern, msg)
 
-    push_coverage_result()
-    exit(not status)
+    push_status = push_coverage_result()
+    exit(not (report_status and push_status))
 
 
 @cli.command()
