@@ -1,4 +1,4 @@
-from vxbase import types
+from vxbase import vtypes
 from docker import from_env
 import subprocess
 import shlex
@@ -39,7 +39,7 @@ def push_image(tags):
         _logger.info('Pushing image %s to %s:%s', environ['_IMAGE_NAME'], environ['_IMAGE_REPO'], tag)
         _cli.tag(environ['_IMAGE_NAME'], environ['_IMAGE_REPO'], tag=tag)
         for result in _cli.push(environ['_IMAGE_REPO'], tag=tag, stream=True):
-            result = json.loads(types.decode(result))
+            result = json.loads(vtypes.decode(result))
             if result.get('error'):
                 _logger.error(result.get('error'))
                 sys.exit(1)
